==> ejc-bid-api-3.0.0-20231023.102305-391-sources.jar: com/ejianc/business/bid/vo/ChoosePersonZiVO.java <==
package com.ejianc.business.bid.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 中标人员选择子实体
 * 
 * @author generator
 * 
 */
public class ChoosePersonZiVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer billState; // 单据状态（审批必须字段）
    private String createUserName; // 编制人
    private Long operatorId; // 经办人ID
    private String operatorName; // 经办人姓名
    private String remark; // 备注
    private Long ryId; // 人员id
    private String ryName; // 人员名字
    private Long gwId; // 岗位id
    private String gw; // 岗位
    private String ssdw; // 所属单位
    private Long pid; // 主表id
    private Integer sfgs; // 是否公式（0：否，1：是）


    public Integer getSfgs() {
        return sfgs;
    }

    public void setSfgs(Integer sfgs) {
        this.sfgs = sfgs;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    @ReferSerialTransfer(referCode = "eperformance_certificate_detail")
    public Long getRyId() {
        return ryId;
    }
    @ReferDeserialTransfer
    public void setRyId(Long ryId) {
        this.ryId = ryId;
    }
    public String getRyName() {
        return ryName;
    }

    public void setRyName(String ryName) {
        this.ryName = ryName;
    }
    @ReferSerialTransfer(referCode = "gwjcda")
    public Long getGwId() {
        return gwId;
    }
    @ReferDeserialTransfer
    public void setGwId(Long gwId) {
        this.gwId = gwId;
    }
    public String getGw() {
        return gw;
    }

    public void setGw(String gw) {
        this.gw = gw;
    }
    public String getSsdw() {
        return ssdw;
    }

    public void setSsdw(String ssdw) {
        this.ssdw = ssdw;
    }
    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    
}

==> ejc-bid-api-3.0.0-20240111.072721-405-sources.jar: com/ejianc/business/bid/vo/ChoosePersonZiVO.java <==
package com.ejianc.business.bid.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 中标人员选择子实体
 * 
 * @author generator
 * 
 */
public class ChoosePersonZiVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer billState; // 单据状态（审批必须字段）
    private String createUserName; // 编制人
    private Long operatorId; // 经办人ID
    private String operatorName; // 经办人姓名
    private String remark; // 备注
    private Long ryId; // 人员id
    private String ryName; // 人员名字
    private Long gwId; // 岗位id
    private String gw; // 岗位
    private String ssdw; // 所属单位
    private Long pid; // 主表id
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    @ReferSerialTransfer(referCode = "idm-employee")
    public Long getRyId() {
        return ryId;
    }
    @ReferDeserialTransfer
    public void setRyId(Long ryId) {
        this.ryId = ryId;
    }
    public String getRyName() {
        return ryName;
    }

    public void setRyName(String ryName) {
        this.ryName = ryName;
    }
    @ReferSerialTransfer(referCode = "gwjcda")
    public Long getGwId() {
        return gwId;
    }
    @ReferDeserialTransfer
    public void setGwId(Long gwId) {
        this.gwId = gwId;
    }
    public String getGw() {
        return gw;
    }

    public void setGw(String gw) {
        this.gw = gw;
    }
    public String getSsdw() {
        return ssdw;
    }

    public void setSsdw(String ssdw) {
        this.ssdw = ssdw;
    }
    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    
}
